@@ -17,6 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #ifndef __GTK_CELL_RENDERER_TOGGLE_H__
 #define __GTK_CELL_RENDERER_TOGGLE_H__
 
@@ -33,17 +37,16 @@ G_BEGIN_DECLS
 #define GTK_IS_CELL_RENDERER_TOGGLE_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_CELL_RENDERER_TOGGLE))
 #define GTK_CELL_RENDERER_TOGGLE_GET_CLASS(obj)         (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_CELL_RENDERER_TOGGLE, GtkCellRendererToggleClass))
 
-typedef struct _GtkCellRendererToggle GtkCellRendererToggle;
-typedef struct _GtkCellRendererToggleClass GtkCellRendererToggleClass;
+typedef struct _GtkCellRendererToggle              GtkCellRendererToggle;
+typedef struct _GtkCellRendererTogglePrivate       GtkCellRendererTogglePrivate;
+typedef struct _GtkCellRendererToggleClass         GtkCellRendererToggleClass;
 
 struct _GtkCellRendererToggle
 {
   GtkCellRenderer parent;
 
   /*< private >*/
-  guint active : 1;
-  guint activatable : 1;
-  guint radio : 1;
+  GtkCellRendererTogglePrivate *priv;
 };
 
 struct _GtkCellRendererToggleClass
@@ -60,19 +63,22 @@ struct _GtkCellRendererToggleClass
   void (*_gtk_reserved4) (void);
 };
 
-GType            gtk_cell_renderer_toggle_get_type  (void) G_GNUC_CONST;
-GtkCellRenderer *gtk_cell_renderer_toggle_new       (void);
+GType            gtk_cell_renderer_toggle_get_type       (void) G_GNUC_CONST;
+GtkCellRenderer *gtk_cell_renderer_toggle_new            (void);
 
-gboolean         gtk_cell_renderer_toggle_get_radio (GtkCellRendererToggle *toggle);
-void             gtk_cell_renderer_toggle_set_radio (GtkCellRendererToggle *toggle,
-						     gboolean               radio);
+gboolean         gtk_cell_renderer_toggle_get_radio      (GtkCellRendererToggle *toggle);
+void             gtk_cell_renderer_toggle_set_radio      (GtkCellRendererToggle *toggle,
+                                                          gboolean               radio);
 
-gboolean        gtk_cell_renderer_toggle_get_active (GtkCellRendererToggle *toggle);
-void            gtk_cell_renderer_toggle_set_active (GtkCellRendererToggle *toggle,
-                                                     gboolean               setting);
+gboolean        gtk_cell_renderer_toggle_get_active      (GtkCellRendererToggle *toggle);
+void            gtk_cell_renderer_toggle_set_active      (GtkCellRendererToggle *toggle,
+                                                          gboolean               setting);
+
+gboolean        gtk_cell_renderer_toggle_get_activatable (GtkCellRendererToggle *toggle);
+void            gtk_cell_renderer_toggle_set_activatable (GtkCellRendererToggle *toggle,
+                                                          gboolean               setting);
 
 
 G_END_DECLS
 
-
 #endif /* __GTK_CELL_RENDERER_TOGGLE_H__ */
