@@ -736,9 +736,8 @@ gtk_style_properties_set_valist (GtkStyleProperties *props,
       if (G_IS_VALUE (val))
         g_value_unset (val);
 
-      g_value_init (val, node->pspec->value_type);
-      G_VALUE_COLLECT (val, args, 0, &error);
-
+      G_VALUE_COLLECT_INIT (val, node->pspec->value_type,
+                            args, 0, &error);
       if (error)
         {
           g_warning ("Could not set style property \"%s\": %s", property_name, error);
@@ -1244,7 +1243,7 @@ gtk_style_properties_merge (GtkStyleProperties       *props,
               font_desc = g_value_get_boxed (value);
               font_desc_to_merge = g_value_get_boxed (&data->value);
 
-              pango_font_description_merge (font_desc, font_desc_to_merge, replace);
+              pango_font_description_merge (font_desc, font_desc_to_merge, FALSE);
             }
           else if (G_VALUE_TYPE (&data->value) == G_TYPE_PTR_ARRAY &&
                    G_IS_VALUE (value))
