@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include <gtk/gtk.h>
 
 static GtkRecentManager *manager = NULL;
@@ -53,7 +53,7 @@ item_activated_cb (GtkRecentChooser *chooser,
 }
 
 static GtkWidget *
-create_recent_chooser_menu (void)
+create_recent_chooser_menu (gint limit)
 {
   GtkWidget *menu;
   GtkRecentFilter *filter;
@@ -61,9 +61,11 @@ create_recent_chooser_menu (void)
   
   menu = gtk_recent_chooser_menu_new_for_manager (manager);
 
-  gtk_recent_chooser_set_limit (GTK_RECENT_CHOOSER (menu), 4);
+  if (limit > 0)
+    gtk_recent_chooser_set_limit (GTK_RECENT_CHOOSER (menu), limit);
   gtk_recent_chooser_set_local_only (GTK_RECENT_CHOOSER (menu), TRUE);
   gtk_recent_chooser_set_show_icons (GTK_RECENT_CHOOSER (menu), TRUE);
+  gtk_recent_chooser_set_show_tips (GTK_RECENT_CHOOSER (menu), TRUE);
   gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (menu),
                                     GTK_RECENT_SORT_MRU);
   gtk_recent_chooser_menu_set_show_numbers (GTK_RECENT_CHOOSER_MENU (menu),
@@ -79,8 +81,6 @@ create_recent_chooser_menu (void)
                     G_CALLBACK (item_activated_cb),
                     NULL);
 
-  gtk_widget_show (menu);
-
   menuitem = gtk_separator_menu_item_new ();
   gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menuitem);
   gtk_widget_show (menuitem);
@@ -101,6 +101,8 @@ create_recent_chooser_menu (void)
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
   gtk_widget_show (menuitem);
 
+  gtk_widget_show_all (menu);
+
   return menu;
 }
 
@@ -122,7 +124,7 @@ create_file_menu (GtkAccelGroup *accelgroup)
   gtk_widget_show (menuitem);
 
   menuitem = gtk_menu_item_new_with_mnemonic ("_Open Recent");
-  recentmenu = create_recent_chooser_menu ();
+  recentmenu = create_recent_chooser_menu (-1);
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), recentmenu);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
   gtk_widget_show (menuitem);
@@ -162,7 +164,7 @@ main (int argc, char *argv[])
   accel_group = gtk_accel_group_new ();
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
   
-  box = gtk_vbox_new (FALSE, 0);
+  box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_add (GTK_CONTAINER (window), box);
   gtk_widget_show (box);
 
@@ -176,7 +178,7 @@ main (int argc, char *argv[])
   gtk_menu_shell_append (GTK_MENU_SHELL (menubar), menuitem);
   gtk_widget_show (menuitem);
 
-  menu = create_recent_chooser_menu ();
+  menu = create_recent_chooser_menu (4);
   menuitem = gtk_menu_item_new_with_mnemonic ("_Recently Used");
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
   gtk_menu_shell_append (GTK_MENU_SHELL (menubar), menuitem);
@@ -191,7 +193,7 @@ main (int argc, char *argv[])
                             G_CALLBACK (gtk_widget_destroy),
                             window);
   gtk_box_pack_end (GTK_BOX (box), button, TRUE, TRUE, 0);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (button, TRUE);
   gtk_widget_grab_default (button);
   gtk_widget_show (button);
 
